==> apache-nuttx-9.1.1-incubating.tar.gz: nuttx/boards/arm/stm32/stm32f4discovery/src/stm32_pca9635.c <==
/****************************************************************************
 * boards/arm/stm32/stm32f4discovery/src/stm32_pca9635.c
 *
 *   Copyright (C) 2014, 2016 Gregory Nutt. All rights reserved.
 *   Author: Gregory Nutt <gnutt@nuttx.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name NuttX nor the names of its contributors may be
 *    used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>

#include <stdbool.h>
#include <stdio.h>
#include <debug.h>
#include <errno.h>

#include <nuttx/i2c/i2c_master.h>
#include <nuttx/leds/pca9635pw.h>

#include <arch/irq.h>

#include "stm32_gpio.h"
#include "stm32_i2c.h"
#include "stm32f4discovery.h"

#ifdef CONFIG_PCA9635PW

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: stm32_pca9635_initialize
 *
 * Description:
 *   This function is called by board initialization logic to configure the
 *   LED PWM chip.  This function will register the driver as /dev/leddrv0.
 *
 * Input Parameters:
 *   None
 *
 * Returned Value:
 *   Zero is returned on success.  Otherwise, a negated errno value is
 *   returned to indicate the nature of the failure.
 *
 ****************************************************************************/

int stm32_pca9635_initialize(void)
{

  FAR struct i2c_master_s *i2c;
  int ret;

  /* Get the I2C driver that interfaces with the pca9635 (PCA9635_I2CBUS)*/

  i2c = stm32_i2cbus_initialize(PCA9635_I2CBUS);
  if (!i2c)
    {
      _err("ERROR: Failed to initialize I2C%d\n", PCA9635_I2CBUS);
      return -1;
    }

  ret = pca9635pw_register("/dev/leddrv0", i2c, PCA9635_I2CADDR);
  if (ret < 0)
    {
      snerr("ERROR: Failed to register PCA9635 driver: %d\n", ret);
     return ret;
    }

  return OK;
}

#endif /* CONFIG_PCA9635PW */

==> apache-nuttx-10.2.0-incubating.tar.gz: nuttx/boards/arm/stm32/stm32f4discovery/src/stm32_pca9635.c <==
/****************************************************************************
 * boards/arm/stm32/stm32f4discovery/src/stm32_pca9635.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>

#include <stdbool.h>
#include <stdio.h>
#include <debug.h>
#include <errno.h>

#include <nuttx/i2c/i2c_master.h>
#include <nuttx/leds/pca9635pw.h>

#include <arch/irq.h>

#include "stm32_gpio.h"
#include "stm32_i2c.h"
#include "stm32f4discovery.h"

#ifdef CONFIG_PCA9635PW

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: stm32_pca9635_initialize
 *
 * Description:
 *   This function is called by board initialization logic to configure the
 *   LED PWM chip.  This function will register the driver as /dev/leddrv0.
 *
 * Input Parameters:
 *   None
 *
 * Returned Value:
 *   Zero is returned on success.  Otherwise, a negated errno value is
 *   returned to indicate the nature of the failure.
 *
 ****************************************************************************/

int stm32_pca9635_initialize(void)
{
  FAR struct i2c_master_s *i2c;
  int ret;

  /* Get the I2C driver that interfaces with the pca9635
   * (PCA9635_I2CBUS)
   */

  i2c = stm32_i2cbus_initialize(PCA9635_I2CBUS);
  if (!i2c)
    {
      _err("ERROR: Failed to initialize I2C%d\n", PCA9635_I2CBUS);
      return -1;
    }

  ret = pca9635pw_register("/dev/leddrv0", i2c, PCA9635_I2CADDR);
  if (ret < 0)
    {
      snerr("ERROR: Failed to register PCA9635 driver: %d\n", ret);
      return ret;
    }

  return OK;
}

#endif /* CONFIG_PCA9635PW */
